A 'shiny' application for forensic kinship testing, based on the 'pedsuite' R packages. 'KLINK' is closely aligned with the (non-R) software 'Familias' and 'FamLink', but offers several unique features, including visualisations and automated report generation. The calculation of likelihood ratios supports pairs of linked markers, and all common mutation models. The program is described in Vigeland and Gilfillan (2026) tools:::Rd_expr_doi("10.1016/j.fsigen.2026.103578").
Maintainer: Magnus Dehli Vigeland m.d.vigeland@medisin.uio.no (ORCID)
Authors:
Magnus Dehli Vigeland m.d.vigeland@medisin.uio.no (ORCID)
Useful links:
tools:::Rd_expr_doi("10.1016/j.fsigen.2026.103578")
Report bugs at https://github.com/magnusdv/KLINK/issues