Learn R Programming

KLINK (version 1.2.2)

loadFamFile: Load .fam file

Description

Load .fam file

Usage

loadFamFile(path, fallbackModel = "equal", withParams = FALSE)

Value

If withParams = FALSE, a list of two pedigree hypotheses in the form of ped objects. If withParams = TRUE, a list with components peds and params.

Arguments

path

The path to a .fam file.

fallbackModel

The name of a mutation model; passed on to pedFamilias::readFam().

withParams

A logical indicating if the Familias parameters should be included in the output. (See pedFamilias::readFam().)

Examples

Run this code
fam = system.file("extdata/halfsib-test.fam", package = "KLINK")
peds = loadFamFile(fam)
pedtools::plotPedList(peds)

loadFamFile(fam, withParams = TRUE)$params

Run the code above in your browser using DataLab