powered by
.fam
Load .fam file
loadFamFile(path, fallbackModel = "equal", withParams = FALSE)
If withParams = FALSE, a list of two pedigree hypotheses in the form of ped objects. If withParams = TRUE, a list with components peds and params.
withParams = FALSE
ped
withParams = TRUE
peds
params
The path to a .fam file.
The name of a mutation model; passed on to pedFamilias::readFam().
pedFamilias::readFam()
A logical indicating if the Familias parameters should be included in the output. (See pedFamilias::readFam().)
fam = system.file("extdata/halfsib-test.fam", package = "KLINK") peds = loadFamFile(fam) pedtools::plotPedList(peds) loadFamFile(fam, withParams = TRUE)$params
Run the code above in your browser using DataLab